@@ -24,6 +24,7 @@ class PyRadiumException(Exception): pass
 class CallingProcessException(PyRadiumException): pass
 
 class MalformedXMLInputException(PyRadiumException): pass
+class MalformedStyleConfigurationException(PyRadiumException): pass
 
 class SlideException(PyRadiumException): pass
 class UndefinedContentException(SlideException): pass
@@ -38,3 +39,9 @@ class InvalidBooleanValueException(PyRadiumException): pass
 class FailedToLookupFileException(PyRadiumException): pass
 
 class FailedToExecuteSubprocessException(PyRadiumException): pass
+
+class SpellcheckerException(PyRadiumException): pass
+
+class StyleParameterException(PyRadiumException): pass
+class InvalidStyleParameterDefinitionException(StyleParameterException): pass
+class InvalidStyleParameterValueException(StyleParameterException): pass
