@@ -22,6 +22,7 @@
 import hashlib
 import subprocess
 import logging
+import pyradium
 import xml.dom.minidom
 from .Tools import XMLTools
 from .TOC import TOCElement, TOCDirective
@@ -102,9 +103,7 @@ class Presentation():
 		return cls(meta, content, sources)
 
 	def _validate_metadata(self):
-		if self.meta is not None:
-			if not isinstance(self.meta.get("schedule", { }), dict):
-				raise MalformedXMLInputException("The 'meta' child node 'schedule' must not contain text, but two child nodes (<total-presentation-time> and <pause-minutes>).")
+		pass
 
 	def _determine_sha256(self, filename):
 		with open(filename, "rb") as f:
@@ -124,7 +123,18 @@ class Presentation():
 
 	@property
 	def version_information(self):
-		return { filename: self._determine_version(filename) for filename in self.sources }
+		return [
+			{
+				"filename":	filename,
+				"version":	self._determine_version(filename),
+			} for filename in self.sources ]
+
+	@property
+	def meta_info(self):
+		return {
+			"renderer":			pyradium.VERSION,
+			"source_versions":	self.version_information,
+		}
 
 	def __iter__(self):
 		return iter(self._content)
