@@ -20,7 +20,9 @@
 #	Johannes Bauer <JohannesBauer@gmx.de>
 
 import json
+import logging
 import mako.lookup
+import markupsafe
 import pyradium
 from pyradium.Controller import ControllerManager
 from pyradium.renderer.LatexFormulaRenderer import LatexFormulaRenderer
@@ -29,9 +31,13 @@ from pyradium.renderer.ExecRenderer import ExecRenderer
 from .Acronyms import Acronyms
 from .RendererCache import RendererCache
 from .RenderedPresentation import RenderedPresentation
-from .Enums import PresentationMode
-from .Exceptions import TemplateErrorException
+from .Exceptions import TemplateErrorException, MalformedStyleConfigurationException
 from .Slide import RenderSlideDirective
+from .Enums import PresentationFeature
+from .Tools import JSONTools
+from .StyleParameters import StyleParameters
+
+_log = logging.getLogger(__spec__.name)
 
 class Renderer():
 	def __init__(self, presentation, rendering_params):
@@ -45,9 +51,26 @@ class Renderer():
 			"acronym":	Acronyms(),
 		}
 		self._lookup = mako.lookup.TemplateLookup(list(self._get_mako_lookup_directories()), strict_undefined = True, input_encoding = "utf-8", default_filters = [ "h" ])
-		with open(self.lookup_styled_template_file("configuration.json")) as f:
+		self._template_config_filename = self.lookup_styled_template_file("configuration.json")
+		with open(self._template_config_filename) as f:
 			self._template_config = json.load(f)
+		self._plausibilize_template_config()
 		self._ctrlr_mgr = ControllerManager(self)
+		self._style_parameters = self._parse_style_parameters()
+
+	def _plausibilize_template_config(self):
+		for feature_name in self._template_config.get("dependencies", { }).get("feature", { }):
+			try:
+				PresentationFeature(feature_name)
+			except ValueError as e:
+				raise MalformedStyleConfigurationException("The stylesheet file %s contains an unknown feature in config[\"dependencies\"][\"feature\"]: %s" % (self._template_config_filename, feature_name)) from e
+
+	def _parse_style_parameters(self):
+		params = StyleParameters(self._template_config.get("parameters", { }))
+		parser = params.new_parser()
+		for param in self._rendering_params.template_style_opts:
+			parser.parse(param)
+		return parser.values
 
 	@property
 	def presentation(self):
@@ -101,11 +124,18 @@ class Renderer():
 		def _template_error(text):
 			raise TemplateErrorException(text)
 
+		def _jsonify(obj):
+			return markupsafe.Markup(json.dumps(JSONTools.round_dict_floats(obj), sort_keys = True, separators = (",", ":")))
+
 		template_args = {
 			"pyradium_version":			pyradium.VERSION,
 			"renderer":					self,
 			"presentation":				self._presentation,
 			"template_error":			_template_error,
+			"jsonify":					_jsonify,
+			"preuri":					self.rendering_params.resource_uri,
+			"preuri_ds":				self.rendering_params.resource_uri if self.rendering_params.resource_uri.startswith("/") else ("./" + self.rendering_params.resource_uri),
+			"styleopt":					self._style_parameters,
 		}
 		if rendered_presentation is not None:
 			template_args["rendered_presentation"] = rendered_presentation
@@ -116,33 +146,53 @@ class Renderer():
 		result = template.render(**template_args)
 		return result
 
-	def render(self, deploy_directory):
-		rendered_presentation = RenderedPresentation(self, deploy_directory = deploy_directory)
+	def render(self, deploy_directory, resource_directory = None):
+		if resource_directory is None:
+			resource_directory = deploy_directory
+		rendered_presentation = RenderedPresentation(self, deploy_directory = deploy_directory, resource_directory = resource_directory)
 
 		for feature in self.rendering_params.presentation_features:
-			rendered_presentation.add_feature(feature.value)
-		if self.rendering_params.presentation_mode == PresentationMode.Interactive:
-			rendered_presentation.add_feature("interactive")
+			rendered_presentation.add_feature(feature)
+		_log.trace("Initial feature set: %s", ", ".join(sorted(feature.name for feature in rendered_presentation.features)))
 
 		# Run it first to build the initial TOC and determine feature set
 		self._compute_renderable_slides(rendered_presentation)
 
-		# Then copy the dependencies
+		_log.debug("Finalized feature set: %s", ", ".join(sorted(feature.name for feature in rendered_presentation.features)))
+
+		# Then copy general dependencies by the used template
 		rendered_presentation.handle_dependencies(self._template_config.get("files"))
+
+		# Additionally look for dependencies which are effective because
+		# specific slide types are used (e.g., a "quote" slide might need its
+		# own CSS)
 		for slide_type in self._determine_slide_types():
-			rendered_presentation.handle_dependencies(self._template_config.get("dependencies", { }).get("slidetype", { }).get(slide_type))
+			slide_type_dependencies = self._template_config.get("dependencies", { }).get("slidetype", { }).get(slide_type)
+			if slide_type_dependencies is not None:
+				for feature_dependency in slide_type_dependencies.get("features", { }):
+					feature_dependency = PresentationFeature(feature_dependency)
+					rendered_presentation.add_feature(feature_dependency)
+				rendered_presentation.handle_dependencies(slide_type_dependencies)
+
+		# Lastly, add dependencies which are effective because a feature flag
+		# is active (e.g., when "interactive" is used, a menu needs to be
+		# generated which requires its own CSS)
 		for feature in rendered_presentation.features:
-			rendered_presentation.handle_dependencies(self._template_config.get("dependencies", { }).get("feature", { }).get(feature))
+			feature_dependency = self._template_config.get("dependencies", { }).get("feature", { }).get(feature.value)
+			rendered_presentation.handle_dependencies(feature_dependency)
 
 		# Then run it again to get the page numbers straight (e.g., the TOC
-		# pages will be emitted, giving different page numbers)
+		# pages will be emitted, giving different page numbers). Initialize
+		# schedule for second run as well.
 		rendered_presentation.finalize_toc()
+		rendered_presentation.init_schedule()
 		self._compute_renderable_slides(rendered_presentation)
 		rendered_presentation.finalize_toc()
 
-		# Compute the schedule
+		# Compute the schedule before the last run
 		rendered_presentation.schedule.compute()
 
+		# Third and final slide run
 		for renderable_slide in self._compute_renderable_slides(rendered_presentation):
 			additional_template_args = {
 				"slide":			renderable_slide,
@@ -152,5 +202,6 @@ class Renderer():
 			rendered_presentation.append_slide(rendered_slide)
 
 		rendered_index = self.render_file("base/index.html", rendered_presentation = rendered_presentation)
-		rendered_presentation.add_file(self.rendering_params.index_filename, rendered_index)
+		rendered_presentation.add_file(self.rendering_params.index_filename, rendered_index, to_deployment_dir = True)
+
 		return rendered_presentation
