@@ -32,3 +32,6 @@ from .TimeHook import TimeHook
 from .ExecHook import ExecHook
 from .MonospaceHook import MonospaceHook
 from .DebugHook import DebugHook
+from .NthHook import NthHook
+from .LinkHook import LinkHook
+from .NoSpellcheckHook import NoSpellcheckHook
